-- <= == == == == == == == == == == == == =>
-- => Option Registration
-- <= == == == == == == == == == == == == =>

if (not PortfolioDemo) then
	PortfolioDemo = {}
end

local Portfolio = LibStub and LibStub("Portfolio")
if not Portfolio then return end

local function callback(id, value, isGUI, isUpdate) 
	Portfolio.Print(id.." callback( \""..tostring(value).."\", "..tostring(isGUI)..", "..tostring(isUpdate)..")")
end

local function colorCallback(id, color, isGUI, isUpdate) 
	(SELECTED_CHAT_FRAME or DEFAULT_CHAT_FRAME)
		:AddMessage(id.." Updated. callback( { r="..tostring(color.r):format("%.2f")..", g="
		..tostring(color.g):format("%.2f")..", b="..tostring(color.b):format("%.2f")..", opacity="
		..tostring(color.opacity).." }, "..tostring(isGUI)..", "..tostring(isUpdate)..") ", 
		color.r, color.g, color.b) 
end


local optionTable = {
	id="PortfolioDemo";
	text="Portfolio Demo";
	addon="PortfolioDemo";
	about=false;
	options = {
		-- Pulls the first header and helptext from the addon toc data
		{
			id = "Checkbox1";
			text = "Checkbox #1";
			tooltipText = "Yay, tooltips are awesome!";
			type = CONTROLTYPE_CHECKBOX;
			defaultValue = "1";
			-- No callback! Just sets the variable.
		};
		{
			id = "Checkbox2";
			text = "Checkbox #2";
			tooltipText = "More tooltipText goodness on hover.";
			type = CONTROLTYPE_CHECKBOX;
			defaultValue = "0";
			callback = function(value, isGUI, isUpdate) callback("Checkbox2", value, isGUI, isUpdate) end;
		};
		{
			id = "ColorPicker1";
			text = "ColorPicker #1";
			tooltipText = "Meh";
			type = CONTROLTYPE_COLORPICKER;
			defaultValue = {r=1, g=0.5, b=0.75};
			callback = function(...) colorCallback("ColorPicker1", ...) end;
			point = {"LEFT", "Checkbox1", "RIGHT", 160, 0};
		};
		{
			id = "ColorPicker2";
			text = "ColorPicker w/ Opacity";
			type = CONTROLTYPE_COLORPICKER;
			hasOpacity = true;
			defaultValue = {r=0.5, g=1, b=0.75, opacity=0.5};
			callback = function(...) colorCallback("ColorPicker2", ...) end;
			point = {"LEFT", "Checkbox2", "RIGHT", 160, 0};
		};
		{
			id = "EditBox1";
			headerText = "EditBox Header";
			tooltipText = "EditBox tooltipText goodness on hover.";
			type = CONTROLTYPE_EDITBOX;
			defaultValue = "Default Text";
			callback = function(...) callback("EditBox1", ...) end;
			point = {nil, "Checkbox2", nil, nil, nil};
		};
		{
			id = "SectionHeader2";
			text = "Header with No Subtext!";
			type = CONTROLTYPE_HEADER;
		};
		{
			id = "SubSet";
			type = CONTROLTYPE_WINDOW;
			height = 160;
			options = {
				{
					id = "Checkbox6";
					text = "Checkbox #6";
					tooltipText = "Tooltip in a sub window... oooo";
					type = CONTROLTYPE_CHECKBOX;
					defaultValue = "1";
					callback = function(value, isGUI, isUpdate) callback("Checkbox6", value, isGUI, isUpdate) end;
				};
				{
					id = "Checkbox7";
					text = "Checkbox #7";
					tooltipText = "Tooltip in a sub window... oooo";
					type = CONTROLTYPE_CHECKBOX;
					defaultValue = "0";
					callback = function(value, isGUI, isUpdate) callback("Checkbox7", value, isGUI, isUpdate) end;
					point = {"LEFT", "Checkbox6", "RIGHT", 140, 0};
				};
				{
					id = "Slider2";
					text = "Slider #2";
					tooltipText = "Slider 2 tooltip goodness on hover.";
					minText = "-10";
					maxText = "10";
					minValue = -10;
					maxValue = 10;
					valueStep = 1;
					type = CONTROLTYPE_SLIDER;
					defaultValue = "0";
					callback = function(...) callback("Slider2", ...) end;
					point = {nil, "Checkbox6", nil, nil, nil};
				};
				{
					id = "Button1";
					text = "Button #1";
					tooltipText = "Whee button tooltip...";
					type = CONTROLTYPE_BUTTON;
					callback = function(...) callback("Button1", ...) end;
				};
				{
					id = "FreeformText";
					text = "Freeform Text: Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.";
					type = CONTROLTYPE_TEXT;
				};
				{
					id = "Button2";
					text = "Button #2";
					tooltipText = "Whee button tooltip...";
					type = CONTROLTYPE_BUTTON;
					callback = function(...) callback("Button2", ...) end;
				};
			};
		};
		{
			id = "SectionHeader1";
			text = "Section Header 1";
			subText = "Even Headers get subText! It goes right bellow them";
			type = CONTROLTYPE_HEADER;
		};
		{
			id = "Dropdown1";
			headerText = "Simple Dropdown";
			type = CONTROLTYPE_DROPDOWN;
			defaultValue = "1";
			-- See UIDropDownMenu.lua for list of button attributes
			menuList = {
				{
					isTitle = 1;
					text = "Level 1";
				};
				{
					text = "Text 1";
					value = "1";
				};
				{
					text = "Text 2";
					value = "2";
				};
				{
					text = "Text 3";
					value = "3";
				};
				{
					text = "Text 4";
					value = "4";
				};
			};
		};
		{
			id = "Dropdown2";
			text = "Override Text (%s)";
			headerText = "Select Something (%s)";
			tooltipText = "Tooltip Text?";
			type = CONTROLTYPE_DROPDOWN;
			defaultValue = "2";
			-- See UIDropDownMenu.lua for list of button attributes
			menuList = {
				{
					isTitle = 1;
					text = "Level 1";
				};
				{
					text = "Text 1";
					value = "1";
				};
				{
					text = "Text 2";
					value = "2";
				};
				{
					text = "Sub Menu";
					hasArrow = 1;
					menuList = {	-- Sub menu
						{
							isTitle = 1;
							text = "Level 2";
						};
						{
							text = "Text 3";
							value = "3";
						};
						{
							text = "Text 4";
							value = "4";
						};
					};
				};
			};
			callback = function(...) callback("Dropdown2", ...) end;
			point = {"TOPLEFT", "Dropdown1", "TOPRIGHT", 30, 0};
		};
		{
			id = "Dropdown3";
			headerText = "Truncated Dropdown";
			type = CONTROLTYPE_DROPDOWN;
			defaultValue = "1";
			width = 100;
			-- See UIDropDownMenu.lua for list of button attributes
			menuList = {
				{
					text = "1 - Very Long Discription";
					value = "1";
				};
				{
					text = "2 - Stuff";
					value = "2";
				};
				{
					text = "3 - UBER_STRING_OF_LONGNESS";
					value = "3";
				};
				{
					text = "4 - \"SOME/PATH/TO/SOMEWHERE\"";
					value = "4";
				};
			};
			point = {nil, "Dropdown1", nil, nil, nil};
		};
		{
			id = "Slider1";
			text = "Slider #1 (%.1f)";
			tooltipText = "Slider tooltip goodness on hover.";
			minText = "Min";
			maxText = "Max";
			minValue = 0;
			maxValue = 10;
			valueStep = 1;
			type = CONTROLTYPE_SLIDER;
			defaultValue = "0";
			callback = function(...) callback("Slider1", ...) end;
		};
		{
			id = "Checkbox3";
			text = "Checkbox #3";
			tooltipText = "Blah Blah Blah Blah\nI have two lines!";
			type = CONTROLTYPE_CHECKBOX;
			defaultValue = "1";
			callback = function(...) callback("Checkbox3", ...) end;
		};
		{
			id = "Checkbox4";
			text = "Checkbox #4";
			tooltipText = "Blah Blah Blah Blah\nI have two lines!";
			type = CONTROLTYPE_CHECKBOX;
			defaultValue = "0";
			callback = function(...) callback("Checkbox4", ...) end;
			point = {"TOPLEFT", "Checkbox3", "TOPRIGHT", 90, 0};
		};
		{
			id = "Checkbox5";
			text = "Checkbox #5";
			tooltipText = "Blah Blah Blah Blah\nI have two lines!";
			type = CONTROLTYPE_CHECKBOX;
			defaultValue = "0";
			callback = function(...) callback("Checkbox5", ...) end;
			point = {"TOPLEFT", "Checkbox4", "TOPRIGHT", 90, 0};
		};
	};
	savedVarTable = "PortfolioDemo_SavedVars";
}

Portfolio.RegisterOptionSet(optionTable)

